==> odoo_16.0.20260107.zip: odoo-16.0.post20260107/odoo/addons/mass_mailing/README.md <==
Odoo Mass Mailing
-----------------

Easily send mass mailing to your leads, opportunities or customers
with Odoo <a href="https://www.odoo.com/app/email-marketing">Email Marketing</a>. Track
marketing campaigns performance to improve conversion rates. Design
professional emails and reuse templates in a few clicks.

Send Professional Emails
------------------------

Import database of prospects or filter on existing leads, opportunities and
customers in just a few clicks.

Define email templates to reuse content or specific design for your newsletter.
Setup several email servers with their own IP/domain to optimise opening rates.

Organize Marketing Campaigns
----------------------------

Design, Send, Track by Campaigns with our <a href="https://www.odoo.com/app/email-marketing">Lead Automation</a> app.

Get real time statistics on campaigns performance to improve your conversion
rate. Track mails sent, received, opened and answered.

Easily manage your marketing campaigns, discussion groups, leads and
opportunities in one simple and powerful platform.

Integrated with Odoo Apps
-------------------------

Get access to mass mailing features from every Odoo app to improve the way your
users communicate.

Send template of emails from Odoo <a href="https://www.odoo.com/app/email-marketing">CRM opportunities</a>, select leads based
on marketing segments, send <a href="https://www.odoo.com/app/recruitment">job offers</a> and automate
answers to applicants, reuse email template in the lead automation marketing
campaigns.

Answers to your emails appears automatically in the history of every document
with the social network module.

Clean Your Lead Database
------------------------

Get a clean lead database that improves over the time using the performance of
your mails. Odoo handle bounce mails efficiently, flag erroneous leads
accordingly and gives you statistics on the quality of your leads.

One click emails send
---------------------

The marketing department will love working on campaigns. But you can also give
a one click mass mailing facility to all others users on their own prospects or
documents.

Select a few documents (e.g. leads, support tickets, suppliers, applicants,
...) and send emails to their contacts in one click, reusing existing emails
templates.

Follow-up On Answers
--------------------

The chatter feature enables you to communicate faster and more efficiently with
your customer. Get documents created automatically (leads, opportunities,
tasks, ...) based on answers to your mass mailing campaigns Follow the
discussion directly on the business documents within Odoo or via email.

Get all the negotiations and discussions attached to the right document and
relevent managers notified on specific events.

Campaigns Dashboard
-------------------

Get the insights you need to make smarter marketing campaign. Track statistics
per campaign: bounce rates, sent mails, best content, etc. The clear dashboards
gives you a direct overview of your campaign performance.

Fully Integrated With Others Apps
---------------------------------

Define automated actions (e.g. ask a salesperson to call, send an email, ...)
based on triggers (no activity since 20 days, answered a promotional email,
etc.)

Optimize campaigns from lead to close, on every channel. Make smarter decisions
about where to invest and show the impact of your marketing activities on your
company's bottom line.

Integrate a contact form in your website easily. Forms submissions create leads
automatically in Odoo CRM. Leads can be used in marketing campaigns.

Manage your <a href="https://www.odoo.com/app/crm">sales funnel</a> with no
effort. Attract leads, follow-up on phone calls and meetings. Analyse the
quality of your leads to make informed decisions and save time by integrating
emails directly into the application.

==> odoo_19.1a1.20251009.zip: odoo-19.1a1.post20251009/odoo/addons/mass_mailing/README.md <==
Odoo Mass Mailing
-----------------

Easily send mass mailing to your leads, opportunities or customers
with Odoo <a href="https://www.odoo.com/app/email-marketing">Email Marketing</a>. Track
marketing campaigns performance to improve conversion rates. Design
professional emails and reuse templates in a few clicks.

Send Professional Emails
------------------------

Import database of prospects or filter on existing leads, opportunities and
customers in just a few clicks.

Define email templates to reuse content or specific design for your newsletter.
Setup several email servers with their own IP/domain to optimise opening rates.

Organize Marketing Campaigns
----------------------------

Design, Send, Track by Campaigns with our <a href="https://www.odoo.com/app/email-marketing">Lead Automation</a> app.

Get real time statistics on campaigns performance to improve your conversion
rate. Track mails sent, received, opened and answered.

Easily manage your marketing campaigns, discussion groups, leads and
opportunities in one simple and powerful platform.

Integrated with Odoo Apps
-------------------------

Get access to mass mailing features from every Odoo app to improve the way your
users communicate.

Send template of emails from Odoo <a href="https://www.odoo.com/app/email-marketing">CRM opportunities</a>, select leads based
on marketing segments, send <a href="https://www.odoo.com/app/recruitment">job offers</a> and automate
answers to applicants, reuse email template in the lead automation marketing
campaigns.

Answers to your emails appears automatically in the history of every document
with the social network module.

Clean Your Lead Database
------------------------

Get a clean lead database that improves over the time using the performance of
your mails. Odoo handle bounce mails efficiently, flag erroneous leads
accordingly and gives you statistics on the quality of your leads.

One click emails send
---------------------

The marketing department will love working on campaigns. But you can also give
a one click mass mailing facility to all others users on their own prospects or
documents.

Select a few documents (e.g. leads, support tickets, suppliers, applicants,
...) and send emails to their contacts in one click, reusing existing emails
templates.

Follow-up On Answers
--------------------

The chatter feature enables you to communicate faster and more efficiently with
your customer. Get documents created automatically (leads, opportunities,
tasks, ...) based on answers to your mass mailing campaigns Follow the
discussion directly on the business documents within Odoo or via email.

Get all the negotiations and discussions attached to the right document and
relevent managers notified on specific events.

Campaigns Dashboard
-------------------

Get the insights you need to make smarter marketing campaign. Track statistics
per campaign: bounce rates, sent mails, best content, etc. The clear dashboards
gives you a direct overview of your campaign performance.

Fully Integrated With Others Apps
---------------------------------

Define automation rules (e.g. ask a salesperson to call, send an email, ...)
based on triggers (no activity since 20 days, answered a promotional email,
etc.)

Optimize campaigns from lead to close, on every channel. Make smarter decisions
about where to invest and show the impact of your marketing activities on your
company's bottom line.

Integrate a contact form in your website easily. Forms submissions create leads
automatically in Odoo CRM. Leads can be used in marketing campaigns.

Manage your <a href="https://www.odoo.com/app/crm">sales funnel</a> with no
effort. Attract leads, follow-up on phone calls and meetings. Analyse the
quality of your leads to make informed decisions and save time by integrating
emails directly into the application.
